# -*- coding: utf-8 -*-

# Copyright © Cloud Linux GmbH & Cloud Linux Software, Inc 2010-2018 All Rights Reserved
#
# Licensed under CLOUD LINUX LICENSE AGREEMENT
# http://cloudlinux.com/docs/LICENSE.TXT
#

from __future__ import absolute_import
from __future__ import division
from __future__ import print_function
import os
import errno
from subprocess import Popen, PIPE
from clcommon.utils import ExternalProgramFailed

CAPTAIN_PATH = '/usr/share/python-cllib/cl.captain'


def captain(do_try, cmd, stdin=None):
    try:
        do_try()
    except (OSError, IOError) as e:
        if e.errno == errno.EDQUOT and os.geteuid() > 0:
            command = [CAPTAIN_PATH] + [str(s) for s in cmd]
            output = Popen(command, stdin=None if stdin is None else PIPE,
                           stdout=PIPE, stderr=PIPE, text=True)
            if stdin is None:
                std_out, std_err = output.communicate()
            else:
                std_out, std_err = output.communicate(stdin)
            if output.returncode != 0:
                raise ExternalProgramFailed(std_err or 'output of "%s": %s' % (
                    ' '.join(command), std_out))
        else:
            raise


def mkdir(path, mode=0o755, recursive=False):
    umask = os.umask(0)
    if recursive:
        collector = "/"
        for subdir in path.split("/"):
            collector = os.path.join(collector, subdir)
            if os.path.exists(collector):
                continue
            captain(lambda: os.mkdir(collector, mode), ['-d', collector, '-m', '%o' % mode])
    else:
        captain(lambda: os.mkdir(path, mode), ['-d', path, '-m', '%o' % mode])
    os.umask(umask)


def write(path, content=''):
    def do_try():
        with open(path, "w") as fp:
            fp.write(content)
            fp.flush()
            os.fsync(fp.fileno())

    captain(do_try, ['-f', path], content)


def symlink(src, dst):
    captain(lambda: os.symlink(src, dst), ['-l', dst, '-s', src])
