#Description

All hooks in the new system are grouped by objects that this event affects.
Those, create one hook to change a domain (any!), another to change a user.
Each hook must have a formal description of the available methods that you can subscribe to.

Example:

    class ModifyUserHook(object):
        HOOK_VERSION = 1
    
        @hook_method
        def pre_create_user(self, username, owner, **kwargs):
            pass
    
        @hook_method
        def post_create_user(self, username, owner, **kwargs):
            pass
    
        @hook_method
        def pre_rename_user(self, username, new_name, **kwargs):
            pass
    
        @hook_method
        def post_rename_user(self, username, new_name, **kwargs):
            pass

It is proposed to form methods according to the template:

    def [post|pre]_(action)_(object)(self, arg1, arg2, **kwargs):

To create a new panel event listener, you need to create a .py file
in the folder `/usr/share/cloudlinux/hooks/listeners/`. 
In that file, you should create class that inherits from one (or several!) 
of universal hooks, and the required methods must be redefined.

    !/opt/alt/python37/bin/python3
    # coding=utf-8
    import subprocess
    import sys
    
    from clcommon.public_hooks.lib import ModifyUserHook, ModifyDomainHook
    
    
    class SyncMapHook(ModifyUserHook, ModifyDomainHook):
    
        @staticmethod
        def call_sync_map():
            # no matter
    
        def post_create_user(self, username, owner, **kwargs):
            self.call_sync_map()
    
        def post_delete_user(self, username, **kwargs):
            self.call_sync_map()
    
        def post_transit_user(self, username, new_name, **kwargs):
            self.call_sync_map()

In the example above, we subscribe to three events: 
- post_create_user;
- post_delete_user;
- post_transit_user.

See detailed description in userland docs.